import { AuthenticationApiImpl, AuthenticationProcess, AuthenticationResult, CryptoPrimitives, CryptoStrategies, DataOwnerWithType, DeviceDto, ErrorHandler, HealthcarePartyDto, KeyStorageFacade, MessageGatewayApi, PatientDto, Sanitizer, StorageFacade } from '@icure/typescript-common';
import { MedTechApi } from './MedTechApi';
import { AuthenticationProvider } from '@icure/api/icc-x-api/auth/AuthenticationProvider';
export interface MedTechAuthenticationResult extends AuthenticationResult<MedTechApi> {
    medTechApi: MedTechApi;
}
export declare class AuthenticationApi extends AuthenticationApiImpl<MedTechApi> {
    private readonly crypto;
    private readonly keyStorage;
    private readonly cryptoStrategies;
    constructor(messageGatewayApi: MessageGatewayApi, iCureBasePath: string, authProcessByEmailId: string | undefined, authProcessBySmsId: string | undefined, errorHandler: ErrorHandler, sanitizer: Sanitizer, crypto: CryptoPrimitives, storage: StorageFacade<string>, keyStorage: KeyStorageFacade, cryptoStrategies: CryptoStrategies<DataOwnerWithType>, msgGtwSpecId: string, msgGtwUrl: string, authProvider?: AuthenticationProvider, fetchImpl?: (input: RequestInfo, init?: RequestInit) => Promise<Response>);
    completeAuthentication(process: AuthenticationProcess, validationCode: string, tokenDurationInSeconds?: number): Promise<MedTechAuthenticationResult>;
    protected initApi(username: string, password: string, initialTokens: {
        token: string;
        refreshToken: string;
    } | undefined): Promise<MedTechApi>;
    protected validateDevice(deviceDto: DeviceDto): void;
    protected validateHcp(hcpDto: HealthcarePartyDto): void;
    protected validatePatient(patientDto: PatientDto): void;
}
export declare const authenticationApi: (errorHandler: ErrorHandler, sanitizer: Sanitizer, messageGatewayApi: MessageGatewayApi, iCureBasePath: string, authProcessByEmailId: string | undefined, authProcessBySmsId: string | undefined, crypto: CryptoPrimitives, storage: StorageFacade<string>, keyStorage: KeyStorageFacade, cryptoStrategies: CryptoStrategies<DataOwnerWithType>, authProvider: AuthenticationProvider, msgGtwSpecId: string, msgGtwUrl: string, fetchImpl?: ((input: RequestInfo, init?: RequestInit) => Promise<Response>) | undefined) => AuthenticationApi;
