"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.authenticationApi = exports.AuthenticationApi = void 0;
const typescript_common_1 = require("@icure/typescript-common");
const MedTechApi_1 = require("./MedTechApi");
class AuthenticationApi extends typescript_common_1.AuthenticationApiImpl {
    constructor(messageGatewayApi, iCureBasePath, authProcessByEmailId, authProcessBySmsId, errorHandler, sanitizer, crypto, storage, keyStorage, cryptoStrategies, msgGtwSpecId, msgGtwUrl, authProvider, fetchImpl = typeof window !== 'undefined' ? window.fetch : typeof self !== 'undefined' ? self.fetch : fetch) {
        super(messageGatewayApi, errorHandler, sanitizer, iCureBasePath, authProcessByEmailId, authProcessBySmsId, storage, msgGtwSpecId, msgGtwUrl, authProvider, fetchImpl);
        this.crypto = crypto;
        this.keyStorage = keyStorage;
        this.cryptoStrategies = cryptoStrategies;
    }
    completeAuthentication(process, validationCode, tokenDurationInSeconds) {
        const _super = Object.create(null, {
            completeAuthentication: { get: () => super.completeAuthentication }
        });
        return __awaiter(this, void 0, void 0, function* () {
            const res = yield _super.completeAuthentication.call(this, process, validationCode, tokenDurationInSeconds);
            return Object.assign(Object.assign({}, res), { medTechApi: res.api });
        });
    }
    initApi(username, password, initialTokens) {
        const builder = new MedTechApi_1.MedTechApi.Builder()
            .withICureBaseUrl(this.iCureBasePath)
            .withUserName(username)
            .withPassword(password)
            .withCrypto(this.crypto)
            .withStorage(this.storage)
            .withKeyStorage(this.keyStorage)
            .withCryptoStrategies(this.cryptoStrategies)
            .withMsgGwSpecId(this.msgGtwSpecId)
            .withMsgGwUrl(this.msgGtwUrl);
        if (!!initialTokens) {
            builder.withInitialTokens(initialTokens);
        }
        if (this.authProcessBySmsId) {
            builder.withAuthProcessBySmsId(this.authProcessBySmsId);
        }
        if (this.authProcessByEmailId) {
            builder.withAuthProcessByEmailId(this.authProcessByEmailId);
        }
        return builder.build();
    }
    validateDevice(deviceDto) {
        return;
    }
    validateHcp(hcpDto) {
        return;
    }
    validatePatient(patientDto) {
        return;
    }
}
exports.AuthenticationApi = AuthenticationApi;
const authenticationApi = (errorHandler, sanitizer, messageGatewayApi, iCureBasePath, authProcessByEmailId, authProcessBySmsId, crypto, storage, keyStorage, cryptoStrategies, authProvider, msgGtwSpecId, msgGtwUrl, fetchImpl) => new AuthenticationApi(messageGatewayApi, iCureBasePath, authProcessByEmailId, authProcessBySmsId, errorHandler, sanitizer, crypto, storage, keyStorage, cryptoStrategies, msgGtwSpecId, msgGtwUrl, authProvider, fetchImpl);
exports.authenticationApi = authenticationApi;
//# sourceMappingURL=AuthenticationApi.js.map