import { AuthenticationApi, CodingApi, DataOwnerApi, DataOwnerWithType, DataSampleApi, HealthcareElementApi, HealthcareProfessionalApi, MedicalDeviceApi, NotificationApi, PatientApi, UserApi } from '../../index';
import { Apis, AuthenticatedApiBuilder, AuthSecretProvider, AuthSecretProviderBridge, CommonApi, CryptoPrimitives, CryptoStrategies, ErrorHandler, IccCryptoXApi, KeyStorageFacade, Sanitizer, StorageFacade } from '@icure/typescript-common';
import { MedTechCryptoStrategies } from '../services/MedTechCryptoStrategies';
import { MedTechMessageFactory } from '../services/MedTechMessageFactory';
export declare class MedTechApi extends CommonApi {
    private readonly _codingApi;
    private readonly _userApi;
    private readonly _patientApi;
    private readonly _healthcareElementApi;
    private readonly _notificationApi;
    private readonly _medicalDeviceApi;
    private readonly _healthcareProfessionalApi;
    private readonly _dataSampleApi;
    private readonly _dataOwnerApi;
    private readonly _cryptoApi;
    private readonly _messageFactory;
    private readonly _iCureBaseUrl;
    private readonly _username;
    private readonly _password;
    private readonly _authSecretProvider;
    private readonly _authenticationApi;
    private readonly _cryptoStrategies;
    constructor(api: Apis, basePath: string, username: string, password: string | undefined, authSecretProvider: AuthSecretProvider | undefined, cryptoStrategies: CryptoStrategies<DataOwnerWithType>, msgGtwUrl?: string | undefined, msgGtwSpecId?: string | undefined, authProcessByEmailId?: string | undefined, authProcessBySmsId?: string | undefined, storage?: StorageFacade<string>, keyStorage?: KeyStorageFacade, messageFactory?: MedTechMessageFactory, errorHandler?: ErrorHandler, sanitizer?: Sanitizer);
    get codingApi(): CodingApi;
    get userApi(): UserApi;
    get patientApi(): PatientApi;
    get healthcareElementApi(): HealthcareElementApi;
    get notificationApi(): NotificationApi;
    get medicalDeviceApi(): MedicalDeviceApi;
    get healthcareProfessionalApi(): HealthcareProfessionalApi;
    get dataSampleApi(): DataSampleApi;
    get dataOwnerApi(): DataOwnerApi;
    get cryptoApi(): IccCryptoXApi;
    get authenticationApi(): AuthenticationApi;
    get iCureBaseUrl(): string;
    get username(): string;
    get password(): string | undefined;
    get authSecretProvider(): AuthSecretProvider | undefined;
    get storage(): StorageFacade<string>;
    get keyStorage(): KeyStorageFacade;
    get messageFactory(): MedTechMessageFactory;
    get cryptoStrategies(): CryptoStrategies<DataOwnerWithType>;
    forceReload(): Promise<void>;
}
export declare function medTechApi(initialisationApi?: MedTechApi): MedTechApi.Builder;
export declare namespace MedTechApi {
    class Builder extends AuthenticatedApiBuilder<MedTechCryptoStrategies, MedTechMessageFactory, MedTechApi> {
        constructor(initialisationApi?: MedTechApi);
        protected doBuild(props: {
            iCureBaseUrl: string;
            msgGwUrl: string;
            msgGwSpecId: string | undefined;
            storage: StorageFacade<string> | undefined;
            keyStorage: KeyStorageFacade | undefined;
            cryptoStrategies: MedTechCryptoStrategies;
            loginDetails: {
                username: string;
                password: string;
            } | {
                icureTokens: {
                    token: string;
                    refreshToken: string;
                };
                credentials: {
                    username: string;
                    password: string;
                };
            } | {
                username: string;
                secretProvider: AuthSecretProviderBridge;
                password: string | undefined;
                initialAuthToken: string | undefined;
                initialRefreshToken: string | undefined;
            };
            crypto: CryptoPrimitives;
            authProcessByEmailId: string | undefined;
            authProcessBySmsId: string | undefined;
            messageFactory: MedTechMessageFactory | undefined;
            errorHandler: ErrorHandler;
            sanitizer: Sanitizer;
        }): Promise<MedTechApi>;
    }
}
