"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.medTechApi = exports.MedTechApi = void 0;
const index_1 = require("../../index");
const typescript_common_1 = require("@icure/typescript-common");
const DataOwner_mapper_1 = require("../mappers/DataOwner.mapper");
const MedTechMessageFactory_1 = require("../services/MedTechMessageFactory");
class MedTechApi extends typescript_common_1.CommonApi {
    constructor(api, basePath, username, password, authSecretProvider, cryptoStrategies, msgGtwUrl = undefined, msgGtwSpecId = undefined, authProcessByEmailId = undefined, authProcessBySmsId = undefined, storage, keyStorage, messageFactory, errorHandler, sanitizer) {
        super(api, username, password, msgGtwUrl, msgGtwSpecId, storage, keyStorage);
        this._iCureBaseUrl = basePath;
        this._username = username;
        this._password = password;
        this._authSecretProvider = authSecretProvider;
        this._messageFactory = messageFactory !== null && messageFactory !== void 0 ? messageFactory : MedTechMessageFactory_1.iCureMedTechMessageFactory;
        this._authenticationApi =
            (authProcessByEmailId || authProcessBySmsId) && this._messageGatewayApi && msgGtwUrl && msgGtwSpecId
                ? (0, index_1.authenticationApi)(this.errorHandler, this.sanitizer, this._messageGatewayApi, basePath, authProcessByEmailId, authProcessBySmsId, api.cryptoApi.primitives, this.storage, this.keyStorage, this.cryptoStrategies, this._baseApi.authApi.authenticationProvider, msgGtwSpecId, msgGtwUrl)
                : undefined;
        this._dataSampleApi = (0, index_1.dataSampleApi)(this, basePath);
        this._codingApi = (0, index_1.codingApi)(this);
        this._medicalDeviceApi = (0, index_1.medicalDeviceApi)(this, basePath);
        this._patientApi = (0, index_1.patientApi)(this, basePath);
        this._userApi = (0, index_1.userApi)(this, this._messageFactory, basePath);
        this._healthcareElementApi = (0, index_1.healthcareElementApi)(this, basePath);
        this._healthcareProfessionalApi = (0, index_1.healthcareProfessionalApi)(this, basePath);
        this._notificationApi = (0, index_1.notificationApi)(this, basePath);
        this._dataOwnerApi = (0, index_1.dataOwnerApi)(this);
        this._cryptoApi = api.cryptoApi;
        this._cryptoStrategies = cryptoStrategies;
    }
    get codingApi() {
        return this._codingApi;
    }
    get userApi() {
        return this._userApi;
    }
    get patientApi() {
        return this._patientApi;
    }
    get healthcareElementApi() {
        return this._healthcareElementApi;
    }
    get notificationApi() {
        return this._notificationApi;
    }
    get medicalDeviceApi() {
        return this._medicalDeviceApi;
    }
    get healthcareProfessionalApi() {
        return this._healthcareProfessionalApi;
    }
    get dataSampleApi() {
        return this._dataSampleApi;
    }
    get dataOwnerApi() {
        return this._dataOwnerApi;
    }
    get cryptoApi() {
        return this._cryptoApi;
    }
    get authenticationApi() {
        if (!this._authenticationApi) {
            throw Error("authenticationApi couldn't be initialized. Make sure you provided the following arguments : msgGwUrl, msgGwSpecId, and at least one of authProcessByEmailId and authProcessBySMSId");
        }
        return this._authenticationApi;
    }
    get iCureBaseUrl() {
        return this._iCureBaseUrl;
    }
    get username() {
        return this._username;
    }
    get password() {
        return this._password;
    }
    get authSecretProvider() {
        return this._authSecretProvider;
    }
    get storage() {
        return this._storage;
    }
    get keyStorage() {
        return this._keyStorage;
    }
    get messageFactory() {
        return this._messageFactory;
    }
    get cryptoStrategies() {
        return this._cryptoStrategies;
    }
    forceReload() {
        return this._cryptoApi.forceReload();
    }
}
exports.MedTechApi = MedTechApi;
function medTechApi(initialisationApi) {
    return new MedTechApi.Builder(initialisationApi);
}
exports.medTechApi = medTechApi;
(function (MedTechApi) {
    class Builder extends typescript_common_1.AuthenticatedApiBuilder {
        constructor(initialisationApi) {
            super();
            if (initialisationApi) {
                super.withICureBaseUrl(initialisationApi.iCureBaseUrl);
                super.withCrypto(initialisationApi.cryptoApi.primitives);
                super.withUserName(initialisationApi.username);
                if (!!initialisationApi.password) {
                    super.withPassword(initialisationApi.password);
                }
                if (!!initialisationApi.authSecretProvider) {
                    super.withAuthSecretProvider(initialisationApi.authSecretProvider);
                }
                super.withStorage(initialisationApi.storage);
                super.withKeyStorage(initialisationApi.keyStorage);
                super.withCryptoStrategies(initialisationApi.cryptoStrategies);
                super.withMessageFactory(initialisationApi.messageFactory);
            }
        }
        doBuild(props) {
            return typescript_common_1.IcureApi.initialise(props.iCureBaseUrl, props.loginDetails, new typescript_common_1.CryptoStrategiesBridge(props.cryptoStrategies, {
                toDomain(dto) {
                    return DataOwner_mapper_1.default.toDomain(dto);
                },
                toDto(domain) {
                    return DataOwner_mapper_1.default.toDto(domain);
                },
            }, (stubWithType) => {
                switch (stubWithType.type) {
                    case typescript_common_1.DataOwnerTypeEnumDto.Patient: {
                        return index_1.DataOwnerTypeEnum.Patient;
                    }
                    case typescript_common_1.DataOwnerTypeEnumDto.Hcp: {
                        return index_1.DataOwnerTypeEnum.HealthcareProfessional;
                    }
                    case typescript_common_1.DataOwnerTypeEnumDto.Device: {
                        return index_1.DataOwnerTypeEnum.MedicalDevice;
                    }
                    default: {
                        throw new Error('Unsupported data owner type');
                    }
                }
            }), props.crypto, fetch, {
                storage: props.storage,
                keyStorage: props.keyStorage,
                createMaintenanceTasksOnNewKey: true,
                disableParentKeysInitialisation: true,
            }).then((api) => new MedTechApi(api, props.iCureBaseUrl, 'username' in props.loginDetails ? props.loginDetails.username : props.loginDetails.credentials.username, 'password' in props.loginDetails ? props.loginDetails.password : props.loginDetails.credentials.password, 'secretProvider' in props.loginDetails ? props.loginDetails.secretProvider.provider : undefined, props.cryptoStrategies, props.msgGwUrl, props.msgGwSpecId, props.authProcessByEmailId, props.authProcessBySmsId, props.storage, props.keyStorage, props.messageFactory, props.errorHandler, props.sanitizer));
        }
    }
    MedTechApi.Builder = Builder;
})(MedTechApi = exports.MedTechApi || (exports.MedTechApi = {}));
//# sourceMappingURL=MedTechApi.js.map