import { CommonApi, CommonFilter, Connection, MessageFactory, PaginatedList, SubscriptionOptions, User, UserDto, UserLikeApi, UserLikeApiImpl } from '@icure/typescript-common';
import { Patient } from '../models/Patient.model';
import { HealthcareProfessional } from '../models/HealthcareProfessional.model';
export interface UserApi extends UserLikeApi<User, Patient> {
    createAndInviteUser(patient: Patient, tokenDuration?: number): Promise<User>;
    createOrModifyUser(user: User): Promise<User>;
    deleteUser(userId: string): Promise<string>;
    filterUsers(filter: CommonFilter<UserDto>, nextUserId?: string, limit?: number): Promise<PaginatedList<User>>;
    getLoggedUser(): Promise<User>;
    getUser(userId: string): Promise<User>;
    getUserByEmail(email: string): Promise<User>;
    matchUsers(filter: CommonFilter<UserDto>): Promise<Array<string>>;
    subscribeToUserEvents(eventTypes: ('CREATE' | 'UPDATE')[], filter: CommonFilter<UserDto>, eventFired: (user: User) => Promise<void>, options?: SubscriptionOptions): Promise<Connection>;
}
declare class UserApiImpl extends UserLikeApiImpl<User, Patient, HealthcareProfessional> implements UserApi {
    createAndInviteUser(patient: Patient, tokenDuration?: number): Promise<User>;
    createOrModifyUser(user: User): Promise<User>;
    deleteUser(userId: string): Promise<string>;
    filterUsers(filter: CommonFilter<UserDto>, nextUserId?: string, limit?: number): Promise<PaginatedList<User>>;
    getLoggedUser(): Promise<User>;
    getUser(userId: string): Promise<User>;
    getUserByEmail(email: string): Promise<User>;
    matchUsers(filter: CommonFilter<UserDto>): Promise<Array<string>>;
    subscribeToUserEvents(eventTypes: ('CREATE' | 'UPDATE')[], filter: CommonFilter<UserDto>, eventFired: (user: User) => Promise<void>, options?: SubscriptionOptions): Promise<Connection>;
}
export declare const userApi: (api: CommonApi, messageFactory: MessageFactory<User, HealthcareProfessional, Patient>, basePath: string) => UserApiImpl;
export {};
