"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.userApi = void 0;
const typescript_common_1 = require("@icure/typescript-common");
const Patient_mapper_1 = require("../mappers/Patient.mapper");
const HealthcareProfessional_mapper_1 = require("../mappers/HealthcareProfessional.mapper");
class UserApiImpl extends typescript_common_1.UserLikeApiImpl {
    createAndInviteUser(patient, tokenDuration) {
        return this.createAndInviteFor(patient, tokenDuration);
    }
    createOrModifyUser(user) {
        return this.createOrModify(user);
    }
    deleteUser(userId) {
        return this.delete(userId);
    }
    filterUsers(filter, nextUserId, limit) {
        return this.filterBy(filter, nextUserId, limit);
    }
    getLoggedUser() {
        return this.getLogged();
    }
    getUser(userId) {
        return this.get(userId);
    }
    getUserByEmail(email) {
        return this.getByEmail(email);
    }
    matchUsers(filter) {
        return this.matchBy(filter);
    }
    subscribeToUserEvents(eventTypes, filter, eventFired, options) {
        return this.subscribeToEvents(eventTypes, filter, eventFired, options);
    }
}
const userApi = (api, messageFactory, basePath) => {
    return new UserApiImpl({
        toDomain(dto) {
            return (0, typescript_common_1.mapUserDtoToUser)(dto);
        },
        toDto(domain) {
            return (0, typescript_common_1.mapUserToUserDto)(domain);
        },
    }, {
        toDomain(dto) {
            return (0, Patient_mapper_1.mapPatientDtoToPatient)(dto);
        },
        toDto(domain) {
            return (0, Patient_mapper_1.mapPatientToPatientDto)(domain);
        },
    }, {
        toDomain(dto) {
            return (0, HealthcareProfessional_mapper_1.mapHealthcarePartyDtoToHealthcareProfessional)(dto);
        },
        toDto(domain) {
            return (0, HealthcareProfessional_mapper_1.mapHealthcareProfessionalToHealthcarePartyDto)(domain);
        },
    }, api.errorHandler, api.sanitizer, api.baseApi.userApi, api.baseApi.dataOwnerApi, api.baseApi.authApi, api, messageFactory, basePath, api.messageGatewayApi);
};
exports.userApi = userApi;
//# sourceMappingURL=UserApi.js.map