"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mapContentToContentDto = exports.mapContentDtoToContent = void 0;
const Content_model_1 = require("../models/Content.model");
const typescript_common_1 = require("@icure/typescript-common");
const DataSample_mapper_1 = require("./DataSample.mapper");
const api_1 = require("@icure/api");
function toContentDtoStringValue(domain) {
    return domain.stringValue;
}
function toContentDtoNumberValue(domain) {
    return domain.numberValue;
}
function toContentDtoBooleanValue(domain) {
    return domain.booleanValue;
}
function toContentDtoInstantValue(domain) {
    return domain.instantValue;
}
function toContentDtoFuzzyDateValue(domain) {
    return domain.fuzzyDateValue;
}
function toContentDtoBinaryValue(domain) {
    return domain.binaryValue ? (0, api_1.b64_2ab)(domain.binaryValue) : undefined;
}
function toContentDtoDocumentId(domain) {
    return domain.documentId;
}
function toContentDtoMeasureValue(domain) {
    return domain.measureValue ? (0, typescript_common_1.mapMeasureToMeasureDto)(domain.measureValue) : undefined;
}
function toContentDtoMedicationValue(domain) {
    return undefined;
}
function toContentDtoTimeSeries(domain) {
    return domain.timeSeries ? (0, typescript_common_1.mapTimeSeriesToTimeSeriesDto)(domain.timeSeries) : undefined;
}
function toContentDtoCompoundValue(domain) {
    var _a;
    return (_a = domain.compoundValue) === null || _a === void 0 ? void 0 : _a.map(DataSample_mapper_1.mapDataSampleToServiceDto);
}
function toContentDtoRatio(domain) {
    var _a;
    return (_a = domain.ratio) === null || _a === void 0 ? void 0 : _a.map(typescript_common_1.mapMeasureToMeasureDto);
}
function toContentDtoRange(domain) {
    var _a;
    return (_a = domain.range) === null || _a === void 0 ? void 0 : _a.map(typescript_common_1.mapMeasureToMeasureDto);
}
function toContentStringValue(dto) {
    return dto.stringValue;
}
function toContentNumberValue(dto) {
    return dto.numberValue;
}
function toContentBooleanValue(dto) {
    return dto.booleanValue;
}
function toContentInstantValue(dto) {
    return dto.instantValue;
}
function toContentFuzzyDateValue(dto) {
    return dto.fuzzyDateValue;
}
function toContentBinaryValue(dto) {
    return dto.binaryValue ? (0, api_1.ua2b64)(dto.binaryValue) : undefined;
}
function toContentDocumentId(dto) {
    return dto.documentId;
}
function toContentMeasureValue(dto) {
    return dto.measureValue ? (0, typescript_common_1.mapMeasureDtoToMeasure)(dto.measureValue) : undefined;
}
function toContentTimeSeries(dto) {
    return dto.timeSeries ? (0, typescript_common_1.mapTimeSeriesDtoToTimeSeries)(dto.timeSeries) : undefined;
}
function toContentCompoundValue(dto) {
    var _a;
    return (_a = dto.compoundValue) === null || _a === void 0 ? void 0 : _a.map(DataSample_mapper_1.mapServiceDtoToDataSample);
}
function toContentRatio(dto) {
    var _a;
    return (_a = dto.ratio) === null || _a === void 0 ? void 0 : _a.map(typescript_common_1.mapMeasureDtoToMeasure);
}
function toContentRange(dto) {
    var _a;
    return (_a = dto.range) === null || _a === void 0 ? void 0 : _a.map(typescript_common_1.mapMeasureDtoToMeasure);
}
function mapContentDtoToContent(dto) {
    return new Content_model_1.Content({
        stringValue: toContentStringValue(dto),
        numberValue: toContentNumberValue(dto),
        booleanValue: toContentBooleanValue(dto),
        instantValue: toContentInstantValue(dto),
        fuzzyDateValue: toContentFuzzyDateValue(dto),
        binaryValue: toContentBinaryValue(dto),
        documentId: toContentDocumentId(dto),
        measureValue: toContentMeasureValue(dto),
        timeSeries: toContentTimeSeries(dto),
        compoundValue: toContentCompoundValue(dto),
        ratio: toContentRatio(dto),
        range: toContentRange(dto),
    });
}
exports.mapContentDtoToContent = mapContentDtoToContent;
function mapContentToContentDto(domain) {
    return new typescript_common_1.ContentDto({
        stringValue: toContentDtoStringValue(domain),
        numberValue: toContentDtoNumberValue(domain),
        booleanValue: toContentDtoBooleanValue(domain),
        instantValue: toContentDtoInstantValue(domain),
        fuzzyDateValue: toContentDtoFuzzyDateValue(domain),
        binaryValue: toContentDtoBinaryValue(domain),
        documentId: toContentDtoDocumentId(domain),
        measureValue: toContentDtoMeasureValue(domain),
        medicationValue: toContentDtoMedicationValue(domain),
        timeSeries: toContentDtoTimeSeries(domain),
        compoundValue: toContentDtoCompoundValue(domain),
        ratio: toContentDtoRatio(domain),
        range: toContentDtoRange(domain),
    });
}
exports.mapContentToContentDto = mapContentToContentDto;
//# sourceMappingURL=Content.mapper.js.map