"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const typescript_common_1 = require("@icure/typescript-common");
const DataOwner_model_1 = require("../models/DataOwner.model");
const Patient_mapper_1 = require("./Patient.mapper");
const HealthcareProfessional_mapper_1 = require("./HealthcareProfessional.mapper");
const MedicalDevice_mapper_1 = require("./MedicalDevice.mapper");
class DataOwnerMapper {
    toDomain({ dataOwner, type }) {
        switch (type) {
            case typescript_common_1.DataOwnerTypeEnumDto.Patient: {
                return {
                    type: DataOwner_model_1.DataOwnerTypeEnum.Patient,
                    dataOwner: (0, Patient_mapper_1.mapPatientDtoToPatient)(dataOwner),
                };
            }
            case typescript_common_1.DataOwnerTypeEnumDto.Hcp: {
                return {
                    type: DataOwner_model_1.DataOwnerTypeEnum.HealthcareProfessional,
                    dataOwner: (0, HealthcareProfessional_mapper_1.mapHealthcarePartyDtoToHealthcareProfessional)(dataOwner),
                };
            }
            case typescript_common_1.DataOwnerTypeEnumDto.Device: {
                return {
                    type: DataOwner_model_1.DataOwnerTypeEnum.MedicalDevice,
                    dataOwner: (0, MedicalDevice_mapper_1.mapDeviceDtoToMedicalDevice)(dataOwner),
                };
            }
            default: {
                throw new Error(`Data owner dto type ${type} not supported`);
            }
        }
    }
    toDto({ dataOwner, type }) {
        if (type === DataOwner_model_1.DataOwnerTypeEnum.Patient) {
            return {
                type: typescript_common_1.DataOwnerTypeEnumDto.Patient,
                dataOwner: (0, Patient_mapper_1.mapPatientToPatientDto)(dataOwner),
            };
        }
        else if (type === DataOwner_model_1.DataOwnerTypeEnum.HealthcareProfessional) {
            return {
                type: typescript_common_1.DataOwnerTypeEnumDto.Hcp,
                dataOwner: (0, HealthcareProfessional_mapper_1.mapHealthcareProfessionalToHealthcarePartyDto)(dataOwner),
            };
        }
        else if (type === DataOwner_model_1.DataOwnerTypeEnum.MedicalDevice) {
            return {
                type: typescript_common_1.DataOwnerTypeEnumDto.Device,
                dataOwner: (0, MedicalDevice_mapper_1.mapMedicalDeviceToDeviceDto)(dataOwner),
            };
        }
        else {
            throw new Error(`Unknown data owner domain type ${type}`);
        }
    }
}
exports.default = new DataOwnerMapper();
//# sourceMappingURL=DataOwner.mapper.js.map