"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mapHealthcareElementToHealthElementDto = exports.mapHealthElementDtoToHealthcareElement = void 0;
const HealthcareElement_model_1 = require("../models/HealthcareElement.model");
const typescript_common_1 = require("@icure/typescript-common");
function toHealthElementDtoId(domain) {
    return (0, typescript_common_1.forceUuid)(domain.id);
}
function toHealthElementDtoIdentifiers(domain) {
    var _a;
    return (_a = domain.identifiers) === null || _a === void 0 ? void 0 : _a.map(typescript_common_1.mapIdentifierToIdentifierDto);
}
function toHealthElementDtoRev(domain) {
    return domain.rev;
}
function toHealthElementDtoCreated(domain) {
    return domain.created;
}
function toHealthElementDtoModified(domain) {
    return domain.modified;
}
function toHealthElementDtoAuthor(domain) {
    return domain.author;
}
function toHealthElementDtoResponsible(domain) {
    return domain.responsible;
}
function toHealthElementDtoMedicalLocationId(domain) {
    return domain.medicalLocationId;
}
function toHealthElementDtoTags(domain) {
    return domain.labels ? [...domain.labels].map(typescript_common_1.mapCodingReferenceToCodeStub) : undefined;
}
function toHealthElementDtoCodes(domain) {
    return domain.codes ? [...domain.codes].map(typescript_common_1.mapCodingReferenceToCodeStub) : undefined;
}
function toHealthElementDtoEndOfLife(domain) {
    return domain.endOfLife;
}
function toHealthElementDtoDeletionDate(domain) {
    return domain.deletionDate;
}
function toHealthElementDtoHealthElementId(domain, initialisedId) {
    var _a;
    return (_a = domain.healthcareElementId) !== null && _a !== void 0 ? _a : initialisedId;
}
function toHealthElementDtoValueDate(domain) {
    return domain.valueDate;
}
function toHealthElementDtoOpeningDate(domain) {
    return domain.openingDate;
}
function toHealthElementDtoClosingDate(domain) {
    return domain.closingDate;
}
function toHealthElementDtoDescr(domain) {
    return domain.description;
}
function toHealthElementDtoNote(domain) {
    return domain.note;
}
function toHealthElementDtoNotes(domain) {
    return domain.notes ? [...domain.notes].map(typescript_common_1.mapAnnotationToAnnotationDto) : undefined;
}
function toHealthElementDtoRelevant(domain) {
    return true;
}
function toHealthElementDtoIdOpeningContact(domain) {
    return undefined;
}
function toHealthElementDtoIdClosingContact(domain) {
    return undefined;
}
function toHealthElementDtoIdService(domain) {
    return undefined;
}
function toHealthElementDtoStatus(domain) {
    return 0;
}
function toHealthElementDtoLaterality(domain) {
    return undefined;
}
function toHealthElementDtoPlansOfAction(domain) {
    return undefined;
}
function toHealthElementDtoEpisodes(domain) {
    return undefined;
}
function toHealthElementDtoCareTeam(domain) {
    return undefined;
}
function toHealthElementDtoSecretForeignKeys(domain) {
    return !!domain.systemMetaData ? (0, typescript_common_1.toSecretForeignKeys)(domain.systemMetaData) : undefined;
}
function toHealthElementDtoCryptedForeignKeys(domain) {
    return !!domain.systemMetaData ? (0, typescript_common_1.toCryptedForeignKeys)(domain.systemMetaData) : undefined;
}
function toHealthElementDtoDelegations(domain) {
    return !!domain.systemMetaData ? (0, typescript_common_1.toDelegations)(domain.systemMetaData) : undefined;
}
function toHealthElementDtoEncryptionKeys(domain) {
    return !!domain.systemMetaData ? (0, typescript_common_1.toEncryptionKeys)(domain.systemMetaData) : undefined;
}
function toHealthElementDtoEncryptedSelf(domain) {
    return !!domain.systemMetaData ? (0, typescript_common_1.toEncryptedSelf)(domain.systemMetaData) : undefined;
}
function toHealthcareElementId(dto) {
    return dto.id;
}
function toHealthcareElementIdentifiers(dto) {
    var _a, _b;
    return (_b = (_a = dto.identifiers) === null || _a === void 0 ? void 0 : _a.map(typescript_common_1.mapIdentifierDtoToIdentifier)) !== null && _b !== void 0 ? _b : [];
}
function toHealthcareElementRev(dto) {
    return dto.rev;
}
function toHealthcareElementCreated(dto) {
    return dto.created;
}
function toHealthcareElementModified(dto) {
    return dto.modified;
}
function toHealthcareElementAuthor(dto) {
    return dto.author;
}
function toHealthcareElementResponsible(dto) {
    return dto.responsible;
}
function toHealthcareElementMedicalLocationId(dto) {
    return dto.medicalLocationId;
}
function toHealthcareElementLabels(dto) {
    var _a, _b;
    return (_b = (_a = dto.tags) === null || _a === void 0 ? void 0 : _a.map(typescript_common_1.mapCodeStubToCodingReference)) !== null && _b !== void 0 ? _b : [];
}
function toHealthcareElementCodes(dto) {
    var _a, _b;
    return (_b = (_a = dto.codes) === null || _a === void 0 ? void 0 : _a.map(typescript_common_1.mapCodeStubToCodingReference)) !== null && _b !== void 0 ? _b : [];
}
function toHealthcareElementEndOfLife(dto) {
    return dto.endOfLife;
}
function toHealthcareElementDeletionDate(dto) {
    return dto.deletionDate;
}
function toHealthcareElementHealthcareElementId(dto) {
    return dto.healthElementId;
}
function toHealthcareElementValueDate(dto) {
    return dto.valueDate;
}
function toHealthcareElementOpeningDate(dto) {
    return dto.openingDate;
}
function toHealthcareElementClosingDate(dto) {
    return dto.closingDate;
}
function toHealthcareElementDescription(dto) {
    return dto.descr;
}
function toHealthcareElementNote(dto) {
    return dto.note;
}
function toHealthcareElementSystemMetaData(dto) {
    return (0, typescript_common_1.toSystemMetaDataEncrypted)(dto);
}
function toHealthcareElementNotes(dto) {
    var _a;
    return (_a = dto.notes) === null || _a === void 0 ? void 0 : _a.map(typescript_common_1.mapAnnotationDtoToAnnotation);
}
function toHealthElementDtoSecurityMetadata(domain) {
    return (0, typescript_common_1.toSecurityMetadataDto)(domain.systemMetaData);
}
function mapHealthElementDtoToHealthcareElement(dto) {
    return new HealthcareElement_model_1.HealthcareElement({
        id: toHealthcareElementId(dto),
        identifiers: toHealthcareElementIdentifiers(dto),
        rev: toHealthcareElementRev(dto),
        created: toHealthcareElementCreated(dto),
        modified: toHealthcareElementModified(dto),
        author: toHealthcareElementAuthor(dto),
        responsible: toHealthcareElementResponsible(dto),
        medicalLocationId: toHealthcareElementMedicalLocationId(dto),
        labels: toHealthcareElementLabels(dto),
        codes: toHealthcareElementCodes(dto),
        endOfLife: toHealthcareElementEndOfLife(dto),
        deletionDate: toHealthcareElementDeletionDate(dto),
        healthcareElementId: toHealthcareElementHealthcareElementId(dto),
        valueDate: toHealthcareElementValueDate(dto),
        openingDate: toHealthcareElementOpeningDate(dto),
        closingDate: toHealthcareElementClosingDate(dto),
        description: toHealthcareElementDescription(dto),
        note: toHealthcareElementNote(dto),
        notes: toHealthcareElementNotes(dto),
        systemMetaData: toHealthcareElementSystemMetaData(dto),
    });
}
exports.mapHealthElementDtoToHealthcareElement = mapHealthElementDtoToHealthcareElement;
function mapHealthcareElementToHealthElementDto(domain) {
    const id = toHealthElementDtoId(domain);
    return new typescript_common_1.HealthElementDto({
        id: id,
        identifiers: toHealthElementDtoIdentifiers(domain),
        rev: toHealthElementDtoRev(domain),
        created: toHealthElementDtoCreated(domain),
        modified: toHealthElementDtoModified(domain),
        author: toHealthElementDtoAuthor(domain),
        responsible: toHealthElementDtoResponsible(domain),
        medicalLocationId: toHealthElementDtoMedicalLocationId(domain),
        tags: toHealthElementDtoTags(domain),
        codes: toHealthElementDtoCodes(domain),
        endOfLife: toHealthElementDtoEndOfLife(domain),
        deletionDate: toHealthElementDtoDeletionDate(domain),
        healthElementId: toHealthElementDtoHealthElementId(domain, id),
        valueDate: toHealthElementDtoValueDate(domain),
        openingDate: toHealthElementDtoOpeningDate(domain),
        closingDate: toHealthElementDtoClosingDate(domain),
        descr: toHealthElementDtoDescr(domain),
        note: toHealthElementDtoNote(domain),
        notes: toHealthElementDtoNotes(domain),
        relevant: toHealthElementDtoRelevant(domain),
        idOpeningContact: toHealthElementDtoIdOpeningContact(domain),
        idClosingContact: toHealthElementDtoIdClosingContact(domain),
        idService: toHealthElementDtoIdService(domain),
        status: toHealthElementDtoStatus(domain),
        laterality: toHealthElementDtoLaterality(domain),
        plansOfAction: toHealthElementDtoPlansOfAction(domain),
        episodes: toHealthElementDtoEpisodes(domain),
        careTeam: toHealthElementDtoCareTeam(domain),
        secretForeignKeys: toHealthElementDtoSecretForeignKeys(domain),
        cryptedForeignKeys: toHealthElementDtoCryptedForeignKeys(domain),
        delegations: toHealthElementDtoDelegations(domain),
        encryptionKeys: toHealthElementDtoEncryptionKeys(domain),
        encryptedSelf: toHealthElementDtoEncryptedSelf(domain),
        securityMetadata: toHealthElementDtoSecurityMetadata(domain),
    });
}
exports.mapHealthcareElementToHealthElementDto = mapHealthcareElementToHealthElementDto;
//# sourceMappingURL=HealthcareElement.mapper.js.map