"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mapMedicalDeviceToDeviceDto = exports.mapDeviceDtoToMedicalDevice = void 0;
const MedicalDevice_model_1 = require("../models/MedicalDevice.model");
const typescript_common_1 = require("@icure/typescript-common");
const api_1 = require("@icure/api");
function toDeviceDtoId(domain) {
    return (0, typescript_common_1.forceUuid)(domain.id);
}
function toDeviceDtoRev(domain) {
    return domain.rev;
}
function toDeviceDtoDeletionDate(domain) {
    return domain.deletionDate;
}
function toDeviceDtoIdentifiers(domain) {
    return domain.identifiers ? [...domain.identifiers].map(typescript_common_1.mapIdentifierToIdentifierDto) : undefined;
}
function toDeviceDtoCreated(domain) {
    return domain.created;
}
function toDeviceDtoModified(domain) {
    return domain.modified;
}
function toDeviceDtoAuthor(domain) {
    return domain.author;
}
function toDeviceDtoResponsible(domain) {
    return domain.responsible;
}
function toDeviceDtoTags(domain) {
    return domain.labels ? [...domain.labels].map(typescript_common_1.mapCodingReferenceToCodeStub) : undefined;
}
function toDeviceDtoCodes(domain) {
    return domain.codes ? [...domain.codes].map(typescript_common_1.mapCodingReferenceToCodeStub) : undefined;
}
function toDeviceDtoEndOfLife(domain) {
    return domain.endOfLife;
}
function toDeviceDtoMedicalLocationId(domain) {
    return undefined;
}
function toDeviceDtoExternalId(domain) {
    return domain.externalId;
}
function toDeviceDtoName(domain) {
    return domain.name;
}
function toDeviceDtoType(domain) {
    return domain.type;
}
function toDeviceDtoBrand(domain) {
    return domain.brand;
}
function toDeviceDtoModel(domain) {
    return domain.model;
}
function toDeviceDtoSerialNumber(domain) {
    return domain.serialNumber;
}
function toDeviceDtoParentId(domain) {
    return domain.parentId;
}
function toDeviceDtoPicture(domain) {
    return domain.picture ? (0, api_1.b64_2ab)(domain.picture) : undefined;
}
function toDeviceDtoProperties(domain) {
    return domain.properties ? [...domain.properties].map(typescript_common_1.mapPropertyToPropertyStub) : undefined;
}
function toDeviceDtoHcPartyKeys(domain) {
    return !!domain.systemMetaData ? (0, typescript_common_1.toHcPartyKeys)(domain.systemMetaData) : undefined;
}
function toDeviceDtoAesExchangeKeys(domain) {
    return !!domain.systemMetaData ? (0, typescript_common_1.toAesExchangeKeys)(domain.systemMetaData) : undefined;
}
function toDeviceDtoTransferKeys(domain) {
    return !!domain.systemMetaData ? (0, typescript_common_1.toTransferKeys)(domain.systemMetaData) : undefined;
}
function toDeviceDtoPrivateKeyShamirPartitions(domain) {
    return !!domain.systemMetaData ? (0, typescript_common_1.toPrivateKeyShamirPartitions)(domain.systemMetaData) : undefined;
}
function toDeviceDtoPublicKey(domain) {
    return !!domain.systemMetaData ? (0, typescript_common_1.toPublicKey)(domain.systemMetaData) : undefined;
}
function toDeviceDtoPublicKeysForOaepWithSha256(domain) {
    return !!domain.systemMetaData ? (0, typescript_common_1.toPublicKeysForOaepWithSha256)(domain.systemMetaData) : undefined;
}
function toMedicalDeviceId(dto) {
    return dto.id;
}
function toMedicalDeviceRev(dto) {
    return dto.rev;
}
function toMedicalDeviceDeletionDate(dto) {
    return dto.deletionDate;
}
function toMedicalDeviceIdentifiers(dto) {
    return dto.identifiers ? [...dto.identifiers].map(typescript_common_1.mapIdentifierDtoToIdentifier) : [];
}
function toMedicalDeviceCreated(dto) {
    return dto.created;
}
function toMedicalDeviceModified(dto) {
    return dto.modified;
}
function toMedicalDeviceAuthor(dto) {
    return dto.author;
}
function toMedicalDeviceResponsible(dto) {
    return dto.responsible;
}
function toMedicalDeviceLabels(dto) {
    return dto.tags ? [...dto.tags].map(typescript_common_1.mapCodeStubToCodingReference) : [];
}
function toMedicalDeviceCodes(dto) {
    return dto.codes ? [...dto.codes].map(typescript_common_1.mapCodeStubToCodingReference) : [];
}
function toMedicalDeviceEndOfLife(dto) {
    return dto.endOfLife;
}
function toMedicalDeviceExternalId(dto) {
    return dto.externalId;
}
function toMedicalDeviceName(dto) {
    return dto.name;
}
function toMedicalDeviceType(dto) {
    return dto.type;
}
function toMedicalDeviceBrand(dto) {
    return dto.brand;
}
function toMedicalDeviceModel(dto) {
    return dto.model;
}
function toMedicalDeviceSerialNumber(dto) {
    return dto.serialNumber;
}
function toMedicalDeviceParentId(dto) {
    return dto.parentId;
}
function toMedicalDevicePicture(dto) {
    return dto.picture ? (0, api_1.ua2b64)(dto.picture) : undefined;
}
function toMedicalDeviceProperties(dto) {
    return dto.properties ? [...dto.properties].map(typescript_common_1.mapPropertyStubToProperty) : [];
}
function toMedicalDeviceSystemMetaData(dto) {
    return (0, typescript_common_1.toSystemMetaDataOwner)(dto);
}
function mapDeviceDtoToMedicalDevice(dto) {
    return new MedicalDevice_model_1.MedicalDevice({
        id: toMedicalDeviceId(dto),
        rev: toMedicalDeviceRev(dto),
        deletionDate: toMedicalDeviceDeletionDate(dto),
        identifiers: toMedicalDeviceIdentifiers(dto),
        created: toMedicalDeviceCreated(dto),
        modified: toMedicalDeviceModified(dto),
        author: toMedicalDeviceAuthor(dto),
        responsible: toMedicalDeviceResponsible(dto),
        labels: toMedicalDeviceLabels(dto),
        codes: toMedicalDeviceCodes(dto),
        endOfLife: toMedicalDeviceEndOfLife(dto),
        externalId: toMedicalDeviceExternalId(dto),
        name: toMedicalDeviceName(dto),
        type: toMedicalDeviceType(dto),
        brand: toMedicalDeviceBrand(dto),
        model: toMedicalDeviceModel(dto),
        serialNumber: toMedicalDeviceSerialNumber(dto),
        parentId: toMedicalDeviceParentId(dto),
        picture: toMedicalDevicePicture(dto),
        properties: toMedicalDeviceProperties(dto),
        systemMetaData: toMedicalDeviceSystemMetaData(dto),
    });
}
exports.mapDeviceDtoToMedicalDevice = mapDeviceDtoToMedicalDevice;
function mapMedicalDeviceToDeviceDto(domain) {
    return new typescript_common_1.DeviceDto({
        id: toDeviceDtoId(domain),
        rev: toDeviceDtoRev(domain),
        deletionDate: toDeviceDtoDeletionDate(domain),
        identifiers: toDeviceDtoIdentifiers(domain),
        created: toDeviceDtoCreated(domain),
        modified: toDeviceDtoModified(domain),
        author: toDeviceDtoAuthor(domain),
        responsible: toDeviceDtoResponsible(domain),
        tags: toDeviceDtoTags(domain),
        codes: toDeviceDtoCodes(domain),
        endOfLife: toDeviceDtoEndOfLife(domain),
        medicalLocationId: toDeviceDtoMedicalLocationId(domain),
        externalId: toDeviceDtoExternalId(domain),
        name: toDeviceDtoName(domain),
        type: toDeviceDtoType(domain),
        brand: toDeviceDtoBrand(domain),
        model: toDeviceDtoModel(domain),
        serialNumber: toDeviceDtoSerialNumber(domain),
        parentId: toDeviceDtoParentId(domain),
        picture: toDeviceDtoPicture(domain),
        properties: toDeviceDtoProperties(domain),
        hcPartyKeys: toDeviceDtoHcPartyKeys(domain),
        aesExchangeKeys: toDeviceDtoAesExchangeKeys(domain),
        transferKeys: toDeviceDtoTransferKeys(domain),
        privateKeyShamirPartitions: toDeviceDtoPrivateKeyShamirPartitions(domain),
        publicKey: toDeviceDtoPublicKey(domain),
        publicKeysForOaepWithSha256: toDeviceDtoPublicKeysForOaepWithSha256(domain),
    });
}
exports.mapMedicalDeviceToDeviceDto = mapMedicalDeviceToDeviceDto;
//# sourceMappingURL=MedicalDevice.mapper.js.map