"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mapPatientToPatientDto = exports.mapPatientDtoToPatient = void 0;
const Patient_model_1 = require("../models/Patient.model");
const typescript_common_1 = require("@icure/typescript-common");
const PersonName_mapper_1 = require("./PersonName.mapper");
const Address_mapper_1 = require("./Address.mapper");
const Partnership_mapper_1 = require("./Partnership.mapper");
const PatientHealthCareParty_mapper_1 = require("./PatientHealthCareParty.mapper");
const api_1 = require("@icure/api");
function toPatientDtoId(domain) {
    return (0, typescript_common_1.forceUuid)(domain.id);
}
function toPatientDtoRev(domain) {
    return domain.rev;
}
function toPatientDtoIdentifier(domain) {
    return domain.identifiers ? [...domain.identifiers].map(typescript_common_1.mapIdentifierToIdentifierDto) : undefined;
}
function toPatientDtoCreated(domain) {
    return domain.created;
}
function toPatientDtoModified(domain) {
    return domain.modified;
}
function toPatientDtoAuthor(domain) {
    return domain.author;
}
function toPatientDtoResponsible(domain) {
    return domain.responsible;
}
function toPatientDtoTags(domain) {
    return domain.labels ? [...domain.labels].map(typescript_common_1.mapCodingReferenceToCodeStub) : undefined;
}
function toPatientDtoCodes(domain) {
    return domain.codes ? [...domain.codes].map(typescript_common_1.mapCodingReferenceToCodeStub) : undefined;
}
function toPatientDtoEndOfLife(domain) {
    return domain.endOfLife;
}
function toPatientDtoDeletionDate(domain) {
    return domain.deletionDate;
}
function toPatientDtoFirstName(domain) {
    return domain.firstName;
}
function toPatientDtoLastName(domain) {
    return domain.lastName;
}
function toPatientDtoNames(domain) {
    return domain.names ? [...domain.names].map(PersonName_mapper_1.mapPersonNameToPersonNameDto) : undefined;
}
function toPatientDtoCompanyName(domain) {
    return domain.companyName;
}
function toPatientDtoLanguages(domain) {
    return domain.languages ? [...domain.languages] : undefined;
}
function toPatientDtoAddresses(domain) {
    return domain.addresses ? [...domain.addresses].map(Address_mapper_1.mapAddressToAddressDto) : undefined;
}
function toPatientDtoCivility(domain) {
    return domain.civility;
}
function toPatientDtoGender(domain) {
    return domain.gender;
}
function toPatientDtoBirthSex(domain) {
    return domain.birthSex;
}
function toPatientDtoMergeToPatientId(domain) {
    return domain.mergeToPatientId;
}
function toPatientDtoMergedIds(domain) {
    return domain.mergedIds ? [...domain.mergedIds] : undefined;
}
function toPatientDtoAlias(domain) {
    return domain.alias;
}
function toPatientDtoActive(domain) {
    return domain.active;
}
function toPatientDtoDeactivationReason(domain) {
    return domain.deactivationReason;
}
function toPatientDtoDeactivationDate(domain) {
    return domain.deactivationDate;
}
function toPatientDtoSsin(domain) {
    return domain.ssin;
}
function toPatientDtoMaidenName(domain) {
    return domain.maidenName;
}
function toPatientDtoSpouseName(domain) {
    return domain.spouseName;
}
function toPatientDtoPartnerName(domain) {
    return domain.partnerName;
}
function toPatientDtoPersonalStatus(domain) {
    return domain.personalStatus;
}
function toPatientDtoDateOfBirth(domain) {
    return domain.dateOfBirth;
}
function toPatientDtoDateOfDeath(domain) {
    return domain.dateOfDeath;
}
function toPatientDtoTimestampOfLatestEidReading(domain) {
    return undefined;
}
function toPatientDtoPlaceOfBirth(domain) {
    return domain.placeOfBirth;
}
function toPatientDtoPlaceOfDeath(domain) {
    return domain.placeOfDeath;
}
function toPatientDtoDeceased(domain) {
    return domain.deceased;
}
function toPatientDtoEducation(domain) {
    return domain.education;
}
function toPatientDtoProfession(domain) {
    return domain.profession;
}
function toPatientDtoNote(domain) {
    return domain.note;
}
function toPatientDtoAdministrativeNote(domain) {
    return domain.administrativeNote;
}
function toPatientDtoNotes(domain) {
    return domain.notes ? [...domain.notes].map(typescript_common_1.mapAnnotationToAnnotationDto) : undefined;
}
function toPatientDtoNationality(domain) {
    return domain.nationality;
}
function toPatientDtoRace(domain) {
    return domain.race;
}
function toPatientDtoEthnicity(domain) {
    return domain.ethnicity;
}
function toPatientDtoPreferredUserId(domain) {
    return undefined;
}
function toPatientDtoPicture(domain) {
    return domain.picture ? (0, api_1.b64_2ab)(domain.picture) : undefined;
}
function toPatientDtoExternalId(domain) {
    return domain.externalId;
}
function toPatientDtoInsurabilities(domain) {
    return undefined;
}
function toPatientDtoPartnerships(domain) {
    return domain.partnerships ? [...domain.partnerships].map(Partnership_mapper_1.mapPartnershipToPartnershipDto) : undefined;
}
function toPatientDtoPatientHealthCareParties(domain) {
    return domain.patientHealthCareParties ? [...domain.patientHealthCareParties].map(PatientHealthCareParty_mapper_1.mapPatientHealthCarePartyToPatientHealthCarePartyDto) : undefined;
}
function toPatientDtoFinancialInstitutionInformation(domain) {
    return undefined;
}
function toPatientDtoMedicalHouseContracts(domain) {
    return undefined;
}
function toPatientDtoPatientProfessions(domain) {
    return domain.patientProfessions ? [...domain.patientProfessions].map(typescript_common_1.mapCodingReferenceToCodeStub) : undefined;
}
function toPatientDtoParameters(domain) {
    return domain.parameters ? Object.fromEntries(Object.entries(domain.parameters)) : undefined;
}
function toPatientDtoProperties(domain) {
    return domain.properties ? [...domain.properties].map(typescript_common_1.mapPropertyToPropertyStub) : undefined;
}
function toPatientDtoHcPartyKeys(domain) {
    return !!domain.systemMetaData ? (0, typescript_common_1.toHcPartyKeys)(domain.systemMetaData) : undefined;
}
function toPatientDtoAesExchangeKeys(domain) {
    return !!domain.systemMetaData ? (0, typescript_common_1.toAesExchangeKeys)(domain.systemMetaData) : undefined;
}
function toPatientDtoTransferKeys(domain) {
    return !!domain.systemMetaData ? (0, typescript_common_1.toTransferKeys)(domain.systemMetaData) : undefined;
}
function toPatientDtoPrivateKeyShamirPartitions(domain) {
    return !!domain.systemMetaData ? (0, typescript_common_1.toPrivateKeyShamirPartitions)(domain.systemMetaData) : undefined;
}
function toPatientDtoPublicKey(domain) {
    return !!domain.systemMetaData ? (0, typescript_common_1.toPublicKey)(domain.systemMetaData) : undefined;
}
function toPatientDtoPublicKeysForOaepWithSha256(domain) {
    return !!domain.systemMetaData ? (0, typescript_common_1.toPublicKeysForOaepWithSha256)(domain.systemMetaData) : undefined;
}
function toPatientDtoSecretForeignKeys(domain) {
    return !!domain.systemMetaData ? (0, typescript_common_1.toSecretForeignKeys)(domain.systemMetaData) : undefined;
}
function toPatientDtoCryptedForeignKeys(domain) {
    return !!domain.systemMetaData ? (0, typescript_common_1.toCryptedForeignKeys)(domain.systemMetaData) : undefined;
}
function toPatientDtoDelegations(domain) {
    return !!domain.systemMetaData ? (0, typescript_common_1.toDelegations)(domain.systemMetaData) : undefined;
}
function toPatientDtoEncryptionKeys(domain) {
    return !!domain.systemMetaData ? (0, typescript_common_1.toEncryptionKeys)(domain.systemMetaData) : undefined;
}
function toPatientDtoEncryptedSelf(domain) {
    return !!domain.systemMetaData ? (0, typescript_common_1.toEncryptedSelf)(domain.systemMetaData) : undefined;
}
function toPatientDtoMedicalLocationId(domain) {
    return undefined;
}
function toPatientDtoNonDuplicateIds(domain) {
    return undefined;
}
function toPatientDtoEncryptedAdministrativesDocuments(domain) {
    return undefined;
}
function toPatientDtoComment(domain) {
    return undefined;
}
function toPatientDtoWarning(domain) {
    return undefined;
}
function toPatientDtoFatherBirthCountry(domain) {
    return undefined;
}
function toPatientDtoBirthCountry(domain) {
    return undefined;
}
function toPatientDtoNativeCountry(domain) {
    return undefined;
}
function toPatientDtoSocialStatus(domain) {
    return undefined;
}
function toPatientDtoMainSourceOfIncome(domain) {
    return undefined;
}
function toPatientDtoSchoolingInfos(domain) {
    return undefined;
}
function toPatientDtoEmployementInfos(domain) {
    return undefined;
}
function toPatientId(dto) {
    return dto.id;
}
function toPatientRev(dto) {
    return dto.rev;
}
function toPatientIdentifiers(dto) {
    return dto.identifier ? dto.identifier.map(typescript_common_1.mapIdentifierDtoToIdentifier) : [];
}
function toPatientCreated(dto) {
    return dto.created;
}
function toPatientModified(dto) {
    return dto.modified;
}
function toPatientAuthor(dto) {
    return dto.author;
}
function toPatientResponsible(dto) {
    return dto.responsible;
}
function toPatientLabels(dto) {
    return dto.tags ? dto.tags.map(typescript_common_1.mapCodeStubToCodingReference) : [];
}
function toPatientCodes(dto) {
    return dto.codes ? dto.codes.map(typescript_common_1.mapCodeStubToCodingReference) : [];
}
function toPatientEndOfLife(dto) {
    return dto.endOfLife;
}
function toPatientDeletionDate(dto) {
    return dto.deletionDate;
}
function toPatientFirstName(dto) {
    return dto.firstName;
}
function toPatientLastName(dto) {
    return dto.lastName;
}
function toPatientNames(dto) {
    return dto.names ? dto.names.map(PersonName_mapper_1.mapPersonNameDtoToPersonName) : [];
}
function toPatientCompanyName(dto) {
    return dto.companyName;
}
function toPatientLanguages(dto) {
    return dto.languages ? dto.languages : [];
}
function toPatientAddresses(dto) {
    return dto.addresses ? dto.addresses.map(Address_mapper_1.mapAddressDtoToAddress) : [];
}
function toPatientCivility(dto) {
    return dto.civility;
}
function toPatientGender(dto) {
    return dto.gender;
}
function toPatientBirthSex(dto) {
    return dto.birthSex;
}
function toPatientMergeToPatientId(dto) {
    return dto.mergeToPatientId;
}
function toPatientMergedIds(dto) {
    return dto.mergedIds ? dto.mergedIds : [];
}
function toPatientAlias(dto) {
    return dto.alias;
}
function toPatientActive(dto) {
    return dto.active;
}
function toPatientDeactivationReason(dto) {
    return dto.deactivationReason;
}
function toPatientSsin(dto) {
    return dto.ssin;
}
function toPatientMaidenName(dto) {
    return dto.maidenName;
}
function toPatientSpouseName(dto) {
    return dto.spouseName;
}
function toPatientPartnerName(dto) {
    return dto.partnerName;
}
function toPatientPersonalStatus(dto) {
    return dto.personalStatus;
}
function toPatientDateOfBirth(dto) {
    return dto.dateOfBirth;
}
function toPatientDateOfDeath(dto) {
    return dto.dateOfDeath;
}
function toPatientPlaceOfBirth(dto) {
    return dto.placeOfBirth;
}
function toPatientPlaceOfDeath(dto) {
    return dto.placeOfDeath;
}
function toPatientDeceased(dto) {
    return dto.deceased;
}
function toPatientEducation(dto) {
    return dto.education;
}
function toPatientProfession(dto) {
    return dto.profession;
}
function toPatientNote(dto) {
    return dto.note;
}
function toPatientAdministrativeNote(dto) {
    return dto.administrativeNote;
}
function toPatientNationality(dto) {
    return dto.nationality;
}
function toPatientRace(dto) {
    return dto.race;
}
function toPatientEthnicity(dto) {
    return dto.ethnicity;
}
function toPatientPicture(dto) {
    return dto.picture ? (0, api_1.ua2b64)(dto.picture) : undefined;
}
function toPatientExternalId(dto) {
    return dto.externalId;
}
function toPatientPartnerships(dto) {
    return dto.partnerships ? dto.partnerships.map(Partnership_mapper_1.mapPartnershipDtoToPartnership) : [];
}
function toPatientPatientHealthCareParties(dto) {
    return dto.patientHealthCareParties ? dto.patientHealthCareParties.map(PatientHealthCareParty_mapper_1.mapPatientHealthCarePartyDtoToPatientHealthCareParty) : [];
}
function toPatientPatientProfessions(dto) {
    return dto.patientProfessions ? dto.patientProfessions.map(typescript_common_1.mapCodeStubToCodingReference) : [];
}
function toPatientParameters(dto) {
    return dto.parameters ? Object.fromEntries(Object.entries(dto.parameters)) : undefined;
}
function toPatientProperties(dto) {
    return dto.properties ? dto.properties.map(typescript_common_1.mapPropertyStubToProperty) : [];
}
function toPatientSystemMetaData(dto) {
    return (0, typescript_common_1.toSystemMetaDataOwnerEncrypted)(dto);
}
function toPatientDeactivationDate(dto) {
    return dto.deactivationDate;
}
function toPatientNotes(dto) {
    return dto.notes ? dto.notes.map(typescript_common_1.mapAnnotationDtoToAnnotation) : undefined;
}
function toPatientDtoSecurityMetadata(domain) {
    return (0, typescript_common_1.toSecurityMetadataDto)(domain.systemMetaData);
}
function mapPatientDtoToPatient(dto) {
    return new Patient_model_1.Patient({
        id: toPatientId(dto),
        rev: toPatientRev(dto),
        identifiers: toPatientIdentifiers(dto),
        created: toPatientCreated(dto),
        modified: toPatientModified(dto),
        author: toPatientAuthor(dto),
        responsible: toPatientResponsible(dto),
        labels: toPatientLabels(dto),
        codes: toPatientCodes(dto),
        endOfLife: toPatientEndOfLife(dto),
        deletionDate: toPatientDeletionDate(dto),
        firstName: toPatientFirstName(dto),
        lastName: toPatientLastName(dto),
        names: toPatientNames(dto),
        companyName: toPatientCompanyName(dto),
        languages: toPatientLanguages(dto),
        addresses: toPatientAddresses(dto),
        civility: toPatientCivility(dto),
        gender: toPatientGender(dto),
        birthSex: toPatientBirthSex(dto),
        mergeToPatientId: toPatientMergeToPatientId(dto),
        mergedIds: toPatientMergedIds(dto),
        alias: toPatientAlias(dto),
        active: toPatientActive(dto),
        deactivationDate: toPatientDeactivationDate(dto),
        deactivationReason: toPatientDeactivationReason(dto),
        ssin: toPatientSsin(dto),
        maidenName: toPatientMaidenName(dto),
        spouseName: toPatientSpouseName(dto),
        partnerName: toPatientPartnerName(dto),
        personalStatus: toPatientPersonalStatus(dto),
        dateOfBirth: toPatientDateOfBirth(dto),
        dateOfDeath: toPatientDateOfDeath(dto),
        placeOfBirth: toPatientPlaceOfBirth(dto),
        placeOfDeath: toPatientPlaceOfDeath(dto),
        deceased: toPatientDeceased(dto),
        education: toPatientEducation(dto),
        profession: toPatientProfession(dto),
        note: toPatientNote(dto),
        notes: toPatientNotes(dto),
        administrativeNote: toPatientAdministrativeNote(dto),
        nationality: toPatientNationality(dto),
        race: toPatientRace(dto),
        ethnicity: toPatientEthnicity(dto),
        picture: toPatientPicture(dto),
        externalId: toPatientExternalId(dto),
        partnerships: toPatientPartnerships(dto),
        patientHealthCareParties: toPatientPatientHealthCareParties(dto),
        patientProfessions: toPatientPatientProfessions(dto),
        parameters: toPatientParameters(dto),
        properties: toPatientProperties(dto),
        systemMetaData: toPatientSystemMetaData(dto),
    });
}
exports.mapPatientDtoToPatient = mapPatientDtoToPatient;
function mapPatientToPatientDto(domain) {
    return new typescript_common_1.PatientDto({
        id: toPatientDtoId(domain),
        rev: toPatientDtoRev(domain),
        identifier: toPatientDtoIdentifier(domain),
        created: toPatientDtoCreated(domain),
        modified: toPatientDtoModified(domain),
        author: toPatientDtoAuthor(domain),
        responsible: toPatientDtoResponsible(domain),
        tags: toPatientDtoTags(domain),
        codes: toPatientDtoCodes(domain),
        endOfLife: toPatientDtoEndOfLife(domain),
        deletionDate: toPatientDtoDeletionDate(domain),
        firstName: toPatientDtoFirstName(domain),
        lastName: toPatientDtoLastName(domain),
        names: toPatientDtoNames(domain),
        companyName: toPatientDtoCompanyName(domain),
        languages: toPatientDtoLanguages(domain),
        addresses: toPatientDtoAddresses(domain),
        civility: toPatientDtoCivility(domain),
        gender: toPatientDtoGender(domain),
        birthSex: toPatientDtoBirthSex(domain),
        mergeToPatientId: toPatientDtoMergeToPatientId(domain),
        mergedIds: toPatientDtoMergedIds(domain),
        alias: toPatientDtoAlias(domain),
        active: toPatientDtoActive(domain),
        deactivationReason: toPatientDtoDeactivationReason(domain),
        deactivationDate: toPatientDtoDeactivationDate(domain),
        ssin: toPatientDtoSsin(domain),
        maidenName: toPatientDtoMaidenName(domain),
        spouseName: toPatientDtoSpouseName(domain),
        partnerName: toPatientDtoPartnerName(domain),
        personalStatus: toPatientDtoPersonalStatus(domain),
        dateOfBirth: toPatientDtoDateOfBirth(domain),
        dateOfDeath: toPatientDtoDateOfDeath(domain),
        timestampOfLatestEidReading: toPatientDtoTimestampOfLatestEidReading(domain),
        placeOfBirth: toPatientDtoPlaceOfBirth(domain),
        placeOfDeath: toPatientDtoPlaceOfDeath(domain),
        deceased: toPatientDtoDeceased(domain),
        education: toPatientDtoEducation(domain),
        profession: toPatientDtoProfession(domain),
        note: toPatientDtoNote(domain),
        administrativeNote: toPatientDtoAdministrativeNote(domain),
        notes: toPatientDtoNotes(domain),
        nationality: toPatientDtoNationality(domain),
        race: toPatientDtoRace(domain),
        ethnicity: toPatientDtoEthnicity(domain),
        preferredUserId: toPatientDtoPreferredUserId(domain),
        picture: toPatientDtoPicture(domain),
        externalId: toPatientDtoExternalId(domain),
        insurabilities: toPatientDtoInsurabilities(domain),
        partnerships: toPatientDtoPartnerships(domain),
        patientHealthCareParties: toPatientDtoPatientHealthCareParties(domain),
        financialInstitutionInformation: toPatientDtoFinancialInstitutionInformation(domain),
        medicalHouseContracts: toPatientDtoMedicalHouseContracts(domain),
        patientProfessions: toPatientDtoPatientProfessions(domain),
        parameters: toPatientDtoParameters(domain),
        properties: toPatientDtoProperties(domain),
        hcPartyKeys: toPatientDtoHcPartyKeys(domain),
        aesExchangeKeys: toPatientDtoAesExchangeKeys(domain),
        transferKeys: toPatientDtoTransferKeys(domain),
        privateKeyShamirPartitions: toPatientDtoPrivateKeyShamirPartitions(domain),
        publicKey: toPatientDtoPublicKey(domain),
        publicKeysForOaepWithSha256: toPatientDtoPublicKeysForOaepWithSha256(domain),
        secretForeignKeys: toPatientDtoSecretForeignKeys(domain),
        cryptedForeignKeys: toPatientDtoCryptedForeignKeys(domain),
        delegations: toPatientDtoDelegations(domain),
        encryptionKeys: toPatientDtoEncryptionKeys(domain),
        encryptedSelf: toPatientDtoEncryptedSelf(domain),
        medicalLocationId: toPatientDtoMedicalLocationId(domain),
        nonDuplicateIds: toPatientDtoNonDuplicateIds(domain),
        encryptedAdministrativesDocuments: toPatientDtoEncryptedAdministrativesDocuments(domain),
        comment: toPatientDtoComment(domain),
        warning: toPatientDtoWarning(domain),
        fatherBirthCountry: toPatientDtoFatherBirthCountry(domain),
        birthCountry: toPatientDtoBirthCountry(domain),
        nativeCountry: toPatientDtoNativeCountry(domain),
        socialStatus: toPatientDtoSocialStatus(domain),
        mainSourceOfIncome: toPatientDtoMainSourceOfIncome(domain),
        schoolingInfos: toPatientDtoSchoolingInfos(domain),
        employementInfos: toPatientDtoEmployementInfos(domain),
        securityMetadata: toPatientDtoSecurityMetadata(domain),
    });
}
exports.mapPatientToPatientDto = mapPatientToPatientDto;
//# sourceMappingURL=Patient.mapper.js.map