import { Annotation, base64string, CodingReference, EntityId, IAnnotation, ICodingReference, Identifier, IIdentifier, IProperty, ISystemMetaDataOwnerEncrypted, Property, SystemMetaDataOwnerEncrypted } from '@icure/typescript-common';
import { Address, IAddress } from './Address.model';
import { IPartnership, Partnership } from './Partnership.model';
import { IPatientHealthCareParty, PatientHealthCareParty } from './PatientHealthCareParty.model';
import { IPersonName, PersonName } from './PersonName.model';
export declare class Patient {
    id: EntityId;
    rev?: string;
    identifiers: Identifier[];
    created?: number;
    modified?: number;
    author?: string;
    responsible?: string;
    labels: CodingReference[];
    codes: CodingReference[];
    endOfLife?: number;
    deletionDate?: number;
    firstName?: string;
    lastName?: string;
    names: PersonName[];
    companyName?: string;
    languages: string[];
    addresses: Address[];
    civility?: string;
    gender?: PatientGenderEnum;
    birthSex?: PatientBirthSexEnum;
    mergeToPatientId?: string;
    mergedIds: string[];
    alias?: string;
    active?: boolean;
    deactivationDate?: number;
    deactivationReason?: PatientDeactivationReasonEnum;
    ssin?: string;
    maidenName?: string;
    spouseName?: string;
    partnerName?: string;
    personalStatus?: PatientPersonalStatusEnum;
    dateOfBirth?: number;
    dateOfDeath?: number;
    placeOfBirth?: string;
    placeOfDeath?: string;
    deceased?: boolean;
    education?: string;
    profession?: string;
    note?: string;
    notes: Annotation[];
    administrativeNote?: string;
    nationality?: string;
    race?: string;
    ethnicity?: string;
    picture?: base64string;
    externalId?: string;
    partnerships: Partnership[];
    patientHealthCareParties: PatientHealthCareParty[];
    patientProfessions: CodingReference[];
    parameters: Record<string, string[]>;
    properties: Property[];
    systemMetaData?: SystemMetaDataOwnerEncrypted;
    toJSON(): IPatient;
    constructor(json: Partial<IPatient>);
}
export interface IPatient {
    id?: EntityId;
    rev?: string;
    identifiers: IIdentifier[];
    created?: number;
    modified?: number;
    author?: string;
    responsible?: string;
    labels: ICodingReference[];
    codes: ICodingReference[];
    endOfLife?: number;
    deletionDate?: number;
    firstName?: string;
    lastName?: string;
    names: IPersonName[];
    companyName?: string;
    languages: string[];
    addresses: IAddress[];
    civility?: string;
    gender?: PatientGenderEnum;
    birthSex?: PatientBirthSexEnum;
    mergeToPatientId?: string;
    mergedIds: string[];
    alias?: string;
    active?: boolean;
    deactivationDate?: number;
    deactivationReason?: PatientDeactivationReasonEnum;
    ssin?: string;
    maidenName?: string;
    spouseName?: string;
    partnerName?: string;
    personalStatus?: PatientPersonalStatusEnum;
    dateOfBirth?: number;
    dateOfDeath?: number;
    placeOfBirth?: string;
    placeOfDeath?: string;
    deceased?: boolean;
    education?: string;
    profession?: string;
    note?: string;
    notes: IAnnotation[];
    administrativeNote?: string;
    nationality?: string;
    race?: string;
    ethnicity?: string;
    picture?: base64string;
    externalId?: string;
    partnerships: IPartnership[];
    patientHealthCareParties: IPatientHealthCareParty[];
    patientProfessions: ICodingReference[];
    parameters?: Record<string, string[]>;
    properties: IProperty[];
    systemMetaData?: ISystemMetaDataOwnerEncrypted;
}
export type PatientGenderEnum = 'male' | 'female' | 'indeterminate' | 'changed' | 'changedToMale' | 'changedToFemale' | 'unknown';
export type PatientBirthSexEnum = 'male' | 'female' | 'indeterminate' | 'changed' | 'changedToMale' | 'changedToFemale' | 'unknown';
export type PatientDeactivationReasonEnum = 'deceased' | 'moved' | 'other_doctor' | 'retired' | 'no_contact' | 'unknown' | 'none';
export type PatientPersonalStatusEnum = 'single' | 'in_couple' | 'married' | 'separated' | 'divorced' | 'divorcing' | 'widowed' | 'widower' | 'complicated' | 'unknown' | 'contract' | 'other' | 'annulled' | 'polygamous';
